<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'info_compresseur_titre' => 'Uttimizazione è cumpressione',
	'info_question_activer_compactage_css' => 'Vulete attivà a cumpressione di e foglie di stile (CSS)?', # MODIF
	'info_question_activer_compactage_js' => 'Vulete attivà a cumpressione di i scripts (javascript)?', # MODIF

	// T
	'texte_compacter_avertissement' => 'Attenti à ùn attivà st’opzioni durante u sviluppu di u situ : L’elementi cumpressi ùn diventenu propriu più leghjitoghji.',
	'texte_compacter_script_css' => 'SPIP pò cumpressà i scripts javascript è e foglie di stile CSS, da arregitrà li in i schedari stàtichi; 
	cusì u situ diventa più veloce.',
	'titre_compacter_script_css' => 'Cumpressione di i scripts è CSS'
);

?>
